#
# spec file for package wayvnc
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wayvnc
Version:        0.9.1
Release:        1.1
Summary:        A VNC server for wlroots based Wayland compositors
License:        ISC
Group:          System/GUI/Other
URL:            https://github.com/any1/wayvnc
Source0:        https://github.com/any1/wayvnc/archive/v%{version}.tar.gz
BuildRequires:  meson
BuildRequires:  neatvnc-devel >= 0.9.0
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  wayland-devel
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(jansson)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdrm_amdgpu)
%ifnarch s390x
BuildRequires:  pkgconfig(libdrm_intel)
%endif
BuildRequires:  pkgconfig(libdrm_nouveau)
BuildRequires:  pkgconfig(libdrm_radeon)
BuildRequires:  pkgconfig(libglvnd)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(opengl)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-egl-backend)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)

%description
This is a VNC server for wlroots based Wayland compositors.
It attaches to a running Wayland session, creates virtual input devices and exposes a single display via the RFB protocol.
The Wayland session may be a headless one, so it is also possible to run wayvnc without a physical display attached.

%prep
%setup -q
find . -type f \( -name '*.c' -o -name '*.h' \) -exec sed -i "s|wayland-client.h|wayland/wayland-client.h|g" {} +

%build
%meson

%meson_build

%install
%meson_install

%files
%license COPYING
%doc README.md
%{_bindir}/wayvnc
%{_bindir}/wayvncctl
%{_mandir}/man1/wayvnc.1%{?ext_man}
%{_mandir}/man1/wayvncctl.1%{?ext_man}

%changelog
* Tue Jan  7 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.9.1:
  * Fix buffer allocation on FreeBSD.
* Tue Jan  7 2025 Michael Vetter <mvetter@suse.com>
- Update to 0.9.0:
  * The new ext-image-copy-capture-v1 protocol has been implemented for output
    capturing.
  * A file descriptor created by a parent process can be used for listening for
    new connections, thanks to Attila Fidan.
  * Clipboard handling has been made more robust, thanks again to Attila Fidan.
  * WayVNC can now allocate CMA backed pixel buffers. They are required for
    hardware encoding on Raspberry Pi.
  * Keyboard LED state can be passed to clients.
  * Output power management is now only enabled while capturing.
* Mon Feb 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.8.0:
  Highlights:
  * Transient seats via the new ext-transient-seat-v1 protocol. These
    are not implemented in any compositor yet, but will hopefully
    be a part of sway 0.10
  * Automatic server-side resizing of headless outputs, by courtesy of Consolatis
  * Detached mode, which allows wayvnc to attach to and detach from a running compositor
  Bugfixes:
  * A crash when trying to attach to a non-wlroots compositor has been fixed.
    Attaching fails, but it doesn't crash.
* Mon Nov  6 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.2:
  * Missing documentation for the websocket flag
  * Null-dereferencing when input is disabled
  * Out-of-bounds memory access when compositors submit out-of-bounds damage
  * Too strict authentication related config parameter sanitation
* Thu Oct  5 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.1:
  * Fix version requirement for Neat VNC
* Thu Oct  5 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.7.0:
  * Each client can now have its own seat, i.e. it's own cursor
    and separate keyboard focus
  * A new option to create a websocket instead of a regular TCP socket
  * Software pixel buffers with fewer bits per pixel than 32 are now supported
  * A new RSA based authentication method with encryption has been added
  * A config file can now reference files relative to the directory
    in which it resides
  * The unix-socket option is fixed
  * Various kinks in wayvncctl have been ironed out
* Thu Jun 29 2023 Joan Torres <joan.torres@suse.com>
- Drop egl, gegl, gles and glx dependencies which aren't needed
  for build.
- libdrm_intel is not required neither available for s390x so stop
  requiring it when is s390x arch.
* Fri Jan 27 2023 Michael Vetter <mvetter@suse.com>
- Prefixe include of wayland-client.h with directory name
* Fri Jan 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.2:
  * This fixes control commands that don't take any parameters
* Tue Jan 24 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.1:
  * Fix compatibility issues with FreeBSD and a few other systems
* Mon Jan 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.6.0:
  New wayvncctl:
  * The captured output can be changed on the fly
  * Connected clients can be listed and managed
  * Various events can be monitored
  Highlights:
  * Control interface, mentioned above.
  * Screen capturing is paused when no client is connected
  * Screen capturing is paused for outputs that are powered off
  * Horizontal scrolling
  * Each client now gets its own set of virtual inputs. This helps
    with state tracking.
  * Symbol to key code mapping now works better with xwayland
* Mon Nov  7 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.5.0:
  * The most significant addition for this release is H.264 encoding
    via the Open H.264 RFB protocol extension. Clients that have
    implemented Open H.264 at this time are TigerVNC and wlvncc,
    of which only the latter uses hardware accelerated decoding.
    H.264 encoding is hardware accelerated and requires the --gpu
    command line flag to be enabled. It isn't particularly useful
    without hardware acceleration, so it's better to stick with
    "Tight" encoding if you don't have GPU rendering.
  * Input can now be disabled
  * UNIX Sockets
  * Screen-capturing via DMA-BUF is now a command line flag (--gpu)
  * Improved logging and error messages
* Mon Jan 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.4.1:
  * main: Pin wl_output version to 3
  * screencopy: Set upper bounds on protocol version
  * main: Set upper bounds on pointer manager version
* Sun Feb 28 2021 Dirk Müller <dmueller@suse.com>
- update to 0.4.0:
  * PAM Authentication, thanks to Nicholas Sica.
  * Faking of modifiers to match keyboard symbols not found at the current shift
  * QEMU extended key event, which uses key codes instead of key symbols. This
    bypasses the need for reverse keyboard symbol mapping for clients that
    support the extension, so the server doesn't need to know about keyboard
    layouts.
  * Xkb config parameters have been added.
* Thu Aug  6 2020 Alexander Graul <alexander.graul@suse.com>
- Update to version 0.2.0
- New features:
  + The OpenGL ES 2.0 based renderer has now been replaced with a pixman based
    renderer. The new renderer is both simpler and performs better on devices
    with poor memory bandwidth such as the Raspberry Pi 3.
  + Extra damage checking is now done using a fash-hash (murmur3) based method,
    rather than comparing frames. This saves memory bandwidth.
  + Experimental support for GPU side wlr-screencopy (wlroots 0.11.0 is
    required).
  + dtrace probes have been added for latency measurements.
- Bugs fixed:
  + Output transformations are now in line with wlroots's output transformation
    behaviour.
  + Shared memory files are now allocated with the correct size rather than zero.
  + Keyboard modifiers no longer get stuck.
  + Wayvnc exits when the compositor goes away rather than crashing.
  + Wayvnc exits when the selected seat or output goes away rather than crashing.
- Default frame rate limit is now 30fps
* Wed Jun  3 2020 Michael Vetter <mvetter@suse.com>
- Initial package of wayvnc 0.1.2 for openSUSE
